@@ -1,13 +1,11 @@
-from energytt_platform.bus.registry import MessageRegistry
+from energytt_platform.bus import message_registry
 
 from .auth import UserOnboarded
 from .measurements import MeasurementAdded
 from .meteringpoints import MeteringPointAdded, MeteringPointRemoved
 
 
-# A registry of all messages understood by the message bus:
-
-registry = MessageRegistry.from_message_types(
+message_registry.add(
     UserOnboarded,
     MeasurementAdded,
     MeteringPointAdded,
