@@ -3,6 +3,11 @@ from dataclasses import dataclass
 
 from energytt_platform.serialize import Serializable
 
+from .common import EnergyDirection
+
+
+MeasurementType = EnergyDirection
+
 
 @dataclass
 class Measurement(Serializable):
@@ -10,3 +15,4 @@ class Measurement(Serializable):
     amount: int
     begin: datetime
     end: datetime
+    type: MeasurementType
